@@ -1,38 +1,17 @@
 weather = {
     0: {'de': None, 'en': None, 'fr': None, 'ja': None},
-    1: {'de': 'Klar',
-        'en': 'Clear Skies',
-        'fr': 'Dégagé',
-        'ja': '快晴'},
-    2: {'de': 'Heiter',
-        'en': 'Fair Skies',
-        'fr': 'Clair',
-        'ja': '晴れ'},
-    3: {'de': 'Wolkig',
-        'en': 'Clouds',
-        'fr': 'Couvert',
-        'ja': '曇り'},
-    4: {'de': 'Neblig',
-        'en': 'Fog',
-        'fr': 'Brouillard',
-        'ja': '霧'},
+    1: {'de': 'Klar', 'en': 'Clear Skies', 'fr': 'Dégagé', 'ja': '快晴'},
+    2: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    3: {'de': 'Wolkig', 'en': 'Clouds', 'fr': 'Couvert', 'ja': '曇り'},
+    4: {'de': 'Neblig', 'en': 'Fog', 'fr': 'Brouillard', 'ja': '霧'},
     5: {'de': 'Windig', 'en': 'Wind', 'fr': 'Vent', 'ja': '風'},
-    6: {'de': 'Stürmisch',
-        'en': 'Gales',
-        'fr': 'Vents violents',
-        'ja': '暴風'},
-    7: {'de': 'Regnerisch',
-        'en': 'Rain',
-        'fr': 'Pluie',
-        'ja': '雨'},
+    6: {'de': 'Stürmisch', 'en': 'Gales', 'fr': 'Vents violents', 'ja': '暴風'},
+    7: {'de': 'Regnerisch', 'en': 'Rain', 'fr': 'Pluie', 'ja': '雨'},
     8: {'de': 'Wolkenbruch',
         'en': 'Showers',
         'fr': 'Pluie torrentielle',
         'ja': '暴雨'},
-    9: {'de': 'Gewittrig',
-        'en': 'Thunder',
-        'fr': 'Orages',
-        'ja': '雷'},
+    9: {'de': 'Gewittrig', 'en': 'Thunder', 'fr': 'Orages', 'ja': '雷'},
     10: {'de': 'Gewitter',
          'en': 'Thunderstorms',
          'fr': 'Orages violents',
@@ -45,94 +24,34 @@ weather = {
          'en': 'Sandstorms',
          'fr': 'Tempêtes de sable',
          'ja': '砂嵐'},
-    13: {'de': 'Heiß',
-         'en': 'Hot Spells',
-         'fr': 'Chaud',
-         'ja': '熱波'},
-    14: {'de': 'Gluthitze',
-         'en': 'Heat Waves',
-         'fr': 'Torride',
-         'ja': '灼熱波'},
-    15: {'de': 'Schnee',
-         'en': 'Snow',
-         'fr': 'Neige',
-         'ja': '雪'},
-    16: {'de': 'Schneesturm',
-         'en': 'Blizzards',
-         'fr': 'Blizzard',
-         'ja': '吹雪'},
-    17: {'de': 'Unheimlich',
-         'en': 'Gloom',
-         'fr': 'Nébuleux',
-         'ja': '妖霧'},
-    18: {'de': 'Aurora',
-         'en': 'Auroras',
-         'fr': 'Aurore',
-         'ja': 'オーロラ'},
-    19: {'de': 'Dunkel',
-         'en': 'Darkness',
-         'fr': 'Ténèbres',
-         'ja': '闇'},
-    20: {'de': 'Düsternis',
-         'en': 'Tension',
-         'fr': 'Désespérance',
-         'ja': '闘気'},
-    21: {'de': 'Wolkig',
-         'en': 'Clouds',
-         'fr': 'Couvert',
-         'ja': '曇り'},
+    13: {'de': 'Heiß', 'en': 'Hot Spells', 'fr': 'Chaud', 'ja': '熱波'},
+    14: {'de': 'Gluthitze', 'en': 'Heat Waves', 'fr': 'Torride', 'ja': '灼熱波'},
+    15: {'de': 'Schnee', 'en': 'Snow', 'fr': 'Neige', 'ja': '雪'},
+    16: {'de': 'Schneesturm', 'en': 'Blizzards', 'fr': 'Blizzard', 'ja': '吹雪'},
+    17: {'de': 'Unheimlich', 'en': 'Gloom', 'fr': 'Nébuleux', 'ja': '妖霧'},
+    18: {'de': 'Aurora', 'en': 'Auroras', 'fr': 'Aurore', 'ja': 'オーロラ'},
+    19: {'de': 'Dunkel', 'en': 'Darkness', 'fr': 'Ténèbres', 'ja': '闇'},
+    20: {'de': 'Düsternis', 'en': 'Tension', 'fr': 'Désespérance', 'ja': '闘気'},
+    21: {'de': 'Wolkig', 'en': 'Clouds', 'fr': 'Couvert', 'ja': '曇り'},
     22: {'de': 'Wetterleuchten',
          'en': 'Storm Clouds',
          'fr': 'Orageux',
          'ja': '雷雲'},
-    23: {'de': 'Tosend',
-         'en': 'Rough Seas',
-         'fr': 'Houle',
-         'ja': '時化'},
-    24: {'de': 'Tosend',
-         'en': 'Rough Seas',
-         'fr': 'Houle',
-         'ja': '時化'},
-    25: {'de': 'Finster',
-         'en': 'Louring',
-         'fr': 'Nuageux',
-         'ja': '曇天'},
-    26: {'de': 'Gluthitze',
-         'en': 'Heat Waves',
-         'fr': 'Torride',
-         'ja': '灼熱波'},
-    27: {'de': 'Unheimlich',
-         'en': 'Gloom',
-         'fr': 'Nébuleux',
-         'ja': '妖霧'},
-    28: {'de': 'Stürmisch',
-         'en': 'Gales',
-         'fr': 'Vents violents',
-         'ja': '暴風'},
+    23: {'de': 'Tosend', 'en': 'Rough Seas', 'fr': 'Houle', 'ja': '時化'},
+    24: {'de': 'Tosend', 'en': 'Rough Seas', 'fr': 'Houle', 'ja': '時化'},
+    25: {'de': 'Finster', 'en': 'Louring', 'fr': 'Nuageux', 'ja': '曇天'},
+    26: {'de': 'Gluthitze', 'en': 'Heat Waves', 'fr': 'Torride', 'ja': '灼熱波'},
+    27: {'de': 'Unheimlich', 'en': 'Gloom', 'fr': 'Nébuleux', 'ja': '妖霧'},
+    28: {'de': 'Stürmisch', 'en': 'Gales', 'fr': 'Vents violents', 'ja': '暴風'},
     29: {'de': 'Rauchschwaden',
          'en': 'Eruptions',
          'fr': 'Éruptions',
          'ja': '噴煙'},
-    30: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
-    31: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
-    32: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
-    33: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
-    34: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
+    30: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    31: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    32: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    33: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    34: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
     35: {'de': 'Blendend',
          'en': 'Irradiance',
          'fr': 'Rayonnement',
@@ -197,14 +116,8 @@ weather = {
          'en': 'Umbral Static',
          'fr': 'Charges ombrales',
          'ja': '放電'},
-    51: {'de': 'Qualm',
-         'en': 'Smoke',
-         'fr': 'Fumées',
-         'ja': '煙霧'},
-    52: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
+    51: {'de': 'Qualm', 'en': 'Smoke', 'fr': 'Fumées', 'ja': '煙霧'},
+    52: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
     53: {'de': 'Königsgewitter',
          'en': 'Royal Levin',
          'fr': 'Éclairs royaux',
@@ -217,18 +130,9 @@ weather = {
          'en': 'Royal Levin',
          'fr': 'Éclairs royaux',
          'ja': '獣雷'},
-    56: {'de': 'Numinos',
-         'en': 'Oppression',
-         'fr': 'Oppression',
-         'ja': '神意'},
-    57: {'de': 'Gewittrig',
-         'en': 'Thunder',
-         'fr': 'Orages',
-         'ja': '雷'},
-    58: {'de': 'Gewittrig',
-         'en': 'Thunder',
-         'fr': 'Orages',
-         'ja': '雷'},
+    56: {'de': 'Numinos', 'en': 'Oppression', 'fr': 'Oppression', 'ja': '神意'},
+    57: {'de': 'Gewittrig', 'en': 'Thunder', 'fr': 'Orages', 'ja': '雷'},
+    58: {'de': 'Gewittrig', 'en': 'Thunder', 'fr': 'Orages', 'ja': '雷'},
     59: {'de': None, 'en': 'CutScene', 'fr': None, 'ja': None},
     60: {'de': 'Mystisch',
          'en': 'Multiplicity',
@@ -238,22 +142,10 @@ weather = {
          'en': 'Multiplicity',
          'fr': 'Multiplicité',
          'ja': '神秘'},
-    62: {'de': 'Regnerisch',
-         'en': 'Rain',
-         'fr': 'Pluie',
-         'ja': '雨'},
-    63: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
-    64: {'de': 'Regnerisch',
-         'en': 'Rain',
-         'fr': 'Pluie',
-         'ja': '雨'},
-    65: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
+    62: {'de': 'Regnerisch', 'en': 'Rain', 'fr': 'Pluie', 'ja': '雨'},
+    63: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    64: {'de': 'Regnerisch', 'en': 'Rain', 'fr': 'Pluie', 'ja': '雨'},
+    65: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
     66: {'de': 'Hass',
          'en': 'Dragonstorms',
          'fr': 'Tempête de haine',
@@ -342,22 +234,13 @@ weather = {
          'en': 'Quicklevin',
          'fr': 'Vif-orage',
          'ja': '迅雷'},
-    88: {'de': 'Gewittrig',
-         'en': 'Thunder',
-         'fr': 'Orages',
-         'ja': '雷'},
+    88: {'de': 'Gewittrig', 'en': 'Thunder', 'fr': 'Orages', 'ja': '雷'},
     89: {'de': 'Dimensionsspaltend',
          'en': 'Dimensional Disruption',
          'fr': 'Perturbation dimensionnelle',
          'ja': '次元'},
-    90: {'de': 'Heiter',
-         'en': 'Fair Skies',
-         'fr': 'Clair',
-         'ja': '晴れ'},
-    91: {'de': 'Klar',
-         'en': 'Clear Skies',
-         'fr': 'Dégagé',
-         'ja': '快晴'},
+    90: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    91: {'de': 'Klar', 'en': 'Clear Skies', 'fr': 'Dégagé', 'ja': '快晴'},
     92: {'de': 'Weißer Zyklon',
          'en': 'White Cyclones',
          'fr': 'Tempête blanche',
@@ -398,70 +281,25 @@ weather = {
           'en': 'Red Moon',
           'fr': 'Lune rouge',
           'ja': '紅月下'},
-    102: {'de': 'Rotlodernd',
-          'en': 'Scarlet',
-          'fr': 'Vermillon',
-          'ja': '朱炎'},
-    103: {'de': 'Rotlodernd',
-          'en': 'Scarlet',
-          'fr': 'Vermillon',
-          'ja': '朱炎'},
-    104: {'de': 'Rotlodernd',
-          'en': 'Scarlet',
-          'fr': 'Vermillon',
-          'ja': '朱炎'},
-    105: {'de': 'Heiter',
-          'en': 'Fair Skies',
-          'fr': 'Clair',
-          'ja': '晴れ'},
-    106: {'de': 'Heiter',
-          'en': 'Fair Skies',
-          'fr': 'Clair',
-          'ja': '晴れ'},
-    107: {'de': 'Heiter',
-          'en': 'Fair Skies',
-          'fr': 'Clair',
-          'ja': '晴れ'},
-    108: {'de': 'Heiter',
-          'en': 'Fair Skies',
-          'fr': 'Clair',
-          'ja': '晴れ'},
-    109: {'de': 'Feuer',
-          'en': 'Flames',
-          'fr': 'Flammes',
-          'ja': '火炎'},
-    110: {'de': 'Tsunami',
-          'en': 'Tsunamis',
-          'fr': 'Raz-de-marée',
-          'ja': '津波'},
-    111: {'de': 'Tornado',
-          'en': 'Cyclones',
-          'fr': 'Tornade',
-          'ja': '竜巻'},
-    112: {'de': 'Erdbeben',
-          'en': 'Geostorms',
-          'fr': 'Séisme',
-          'ja': '地震'},
-    113: {'de': 'Blauschimmernd',
-          'en': 'True Blue',
-          'fr': 'Azur',
-          'ja': '青春'},
-    114: {'de': 'Blauschimmernd',
-          'en': 'True Blue',
-          'fr': 'Azur',
-          'ja': '青春'},
-    115: {'de': 'Blauschimmernd',
-          'en': 'True Blue',
-          'fr': 'Azur',
-          'ja': '青春'},
+    102: {'de': 'Rotlodernd', 'en': 'Scarlet', 'fr': 'Vermillon', 'ja': '朱炎'},
+    103: {'de': 'Rotlodernd', 'en': 'Scarlet', 'fr': 'Vermillon', 'ja': '朱炎'},
+    104: {'de': 'Rotlodernd', 'en': 'Scarlet', 'fr': 'Vermillon', 'ja': '朱炎'},
+    105: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    106: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    107: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    108: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
+    109: {'de': 'Feuer', 'en': 'Flames', 'fr': 'Flammes', 'ja': '火炎'},
+    110: {'de': 'Tsunami', 'en': 'Tsunamis', 'fr': 'Raz-de-marée', 'ja': '津波'},
+    111: {'de': 'Tornado', 'en': 'Cyclones', 'fr': 'Tornade', 'ja': '竜巻'},
+    112: {'de': 'Erdbeben', 'en': 'Geostorms', 'fr': 'Séisme', 'ja': '地震'},
+    113: {'de': 'Blauschimmernd', 'en': 'True Blue', 'fr': 'Azur', 'ja': '青春'},
+    114: {'de': 'Blauschimmernd', 'en': 'True Blue', 'fr': 'Azur', 'ja': '青春'},
+    115: {'de': 'Blauschimmernd', 'en': 'True Blue', 'fr': 'Azur', 'ja': '青春'},
     116: {'de': 'Astrale Turbulenzen',
           'en': 'Umbral Turbulence',
           'fr': 'Turbulences ombrales',
           'ja': '乱霊流'},
-    117: {'de': 'Blauschimmernd',
-          'en': 'True Blue',
-          'fr': 'Azur',
-          'ja': '青春'},
+    117: {'de': 'Blauschimmernd', 'en': 'True Blue', 'fr': 'Azur', 'ja': '青春'},
     118: {'de': 'Ewiges Licht',
           'en': 'Everlasting Light',
           'fr': 'Clarté éternelle',
@@ -478,18 +316,9 @@ weather = {
           'en': 'Termination',
           'fr': 'Apocalypse',
           'ja': '終末'},
-    122: {'de': 'Feenträume',
-          'en': 'Dreams',
-          'fr': 'Rêverie',
-          'ja': '妖夢'},
-    123: {'de': 'Feenträume',
-          'en': 'Dreams',
-          'fr': 'Rêverie',
-          'ja': '妖夢'},
-    124: {'de': 'Feenträume',
-          'en': 'Dreams',
-          'fr': 'Rêverie',
-          'ja': '妖夢'},
+    122: {'de': 'Feenträume', 'en': 'Dreams', 'fr': 'Rêverie', 'ja': '妖夢'},
+    123: {'de': 'Feenträume', 'en': 'Dreams', 'fr': 'Rêverie', 'ja': '妖夢'},
+    124: {'de': 'Feenträume', 'en': 'Dreams', 'fr': 'Rêverie', 'ja': '妖夢'},
     125: {'de': 'Strahlende Glanzhaftigkeit',
           'en': 'Brilliance',
           'fr': 'Radiance divine',
@@ -518,10 +347,7 @@ weather = {
           'en': 'Termination',
           'fr': 'Apocalypse',
           'ja': '終末'},
-    132: {'de': 'Heiter',
-          'en': 'Fair Skies',
-          'fr': 'Clair',
-          'ja': '晴れ'},
+    132: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
     133: {'de': 'Feuerseelenwinde',
           'en': 'Umbral Flare',
           'fr': 'Vent ombral de feu',
@@ -546,14 +372,8 @@ weather = {
           'en': 'Delirium',
           'fr': 'Tempête de souvenirs',
           'ja': '記憶乱流'},
-    139: {'de': 'Wolkig',
-          'en': 'Clouds',
-          'fr': 'Couvert',
-          'ja': '曇り'},
-    140: {'de': 'Wolkig',
-          'en': 'Clouds',
-          'fr': 'Couvert',
-          'ja': '曇り'},
+    139: {'de': 'Wolkig', 'en': 'Clouds', 'fr': 'Couvert', 'ja': '曇り'},
+    140: {'de': 'Wolkig', 'en': 'Clouds', 'fr': 'Couvert', 'ja': '曇り'},
     141: {'de': 'Blendend',
           'en': 'Irradiance',
           'fr': 'Rayonnement',
@@ -575,10 +395,7 @@ weather = {
           'fr': 'Courant spectral',
           'ja': '幻海流\xa0'},
     146: {'de': None, 'en': None, 'fr': None, 'ja': None},
-    147: {'de': 'Endzeitig',
-          'en': 'Climactic',
-          'fr': 'Fatidique',
-          'ja': '決戦'},
+    147: {'de': 'Endzeitig', 'en': 'Climactic', 'fr': 'Fatidique', 'ja': '決戦'},
     148: {'de': 'Mondstaubig',
           'en': 'Moon Dust',
           'fr': 'Tempêtes de régolithe',
@@ -611,13 +428,19 @@ weather = {
           'en': 'Polarization',
           'fr': 'Polarisation',
           'ja': '星霊'},
-    156: {'de': 'Imaginär',
-          'en': 'Projection',
-          'fr': 'Virtuel',
-          'ja': '仮想'},
-    157: {'de': None, 'en': None, 'fr': None, 'ja': None},
-    158: {'de': None, 'en': None, 'fr': None, 'ja': None},
-    159: {'de': None, 'en': None, 'fr': None, 'ja': None},
+    156: {'de': 'Imaginär', 'en': 'Projection', 'fr': 'Virtuel', 'ja': '仮想'},
+    157: {'de': 'Pandæmonium',
+          'en': 'Pandæmonium',
+          'fr': 'Pandæmonium',
+          'ja': '万魔殿'},
+    158: {'de': 'Pandæmonium',
+          'en': 'Pandæmonium',
+          'fr': 'Pandæmonium',
+          'ja': '万魔殿'},
+    159: {'de': 'Pandæmonium',
+          'en': 'Pandæmonium',
+          'fr': 'Pandæmonium',
+          'ja': '万魔殿'},
     160: {'de': 'Eschatologie',
           'en': 'Ultimatum',
           'fr': 'Eschatologique',
@@ -625,5 +448,44 @@ weather = {
     161: {'de': 'Verzweifelnd',
           'en': 'Inevitability',
           'fr': 'Désespoir',
-          'ja': '絶望'}
+          'ja': '絶望'},
+    162: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    163: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    164: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    165: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    166: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    167: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    168: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    169: {'de': 'Götterwetter',
+          'en': 'Transcendence',
+          'fr': 'Mythologique',
+          'ja': '神域'},
+    170: {'de': 'Hass',
+          'en': 'Dragonstorms',
+          'fr': 'Tempête de haine',
+          'ja': '邪天'},
+    171: {'de': 'Leere', 'en': 'Vacuity', 'fr': 'Néant', 'ja': '虚無'},
+    172: {'de': 'Leere', 'en': 'Vacuity', 'fr': 'Néant', 'ja': '虚無'},
+    173: {'de': 'Leere', 'en': 'Vacuity', 'fr': 'Néant', 'ja': '虚無'}
 }
